Stan Math Library: stan/math/rev/mat/vectorize/apply_scalar_unary.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
apply_scalar_unary.hpp File Reference
`#include <stan/math/prim/mat/vectorize/apply_scalar_unary.hpp>`
`#include <stan/math/rev/core/var.hpp>`

Go to the source code of this file.

## Classes
struct | stan::math::apply_scalar_unary< F, stan::math::var >
| Template specialization to var for vectorizing a unary scalar function. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.